==> haskell-commutative-semigroups-0.2.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commutative-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commutative-semigroups
version:              0.2.0.1
visibility:           public
id:                   commutative-semigroups-0.2.0.1-8XLwNFnEO8JH5WoKEjdOs6
key:                  commutative-semigroups-0.2.0.1-8XLwNFnEO8JH5WoKEjdOs6
license:              BSD-3-Clause
copyright:
    Copyright (C) 2013 Nathan van Doorn, 2021–2022 Obsidian Systems LLC

maintainer:           maintainer@obsidian.systems
author:               Nathan "Taneb" van Doorn
synopsis:             Commutative semigroups
description:
    A commutative semigroup is a semigroup where the order of arguments to mappend does not matter.

category:             Algebra, Data, Math
abi:                  b5d156f0377d5c4e1817007b645bfb88
exposed:              True
exposed-modules:
    Data.Semigroup.Commutative Numeric.Product.Commutative

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/commutative-semigroups-0.2.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/commutative-semigroups-0.2.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/commutative-semigroups-0.2.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commutative-semigroups
hs-libraries:         HScommutative-semigroups-0.2.0.1-8XLwNFnEO8JH5WoKEjdOs6
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:
    /usr/share/doc/haskell-commutative-semigroups/html/commutative-semigroups.haddock

haddock-html:         /usr/share/doc/haskell-commutative-semigroups/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commutative-semigroups-0.2.0.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commutative-semigroups.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commutative-semigroups
version:              0.2.0.2
visibility:           public
id:                   commutative-semigroups-0.2.0.2-KKbxYpGvMjb9AEMnknsNP1
key:                  commutative-semigroups-0.2.0.2-KKbxYpGvMjb9AEMnknsNP1
license:              BSD-3-Clause
copyright:
    Copyright (C) 2013 Nathan van Doorn, 2021–2022 Obsidian Systems LLC

maintainer:           maintainer@obsidian.systems
author:               Nathan "Taneb" van Doorn
synopsis:             Commutative semigroups
description:
    A commutative semigroup is a semigroup where the order of arguments to mappend does not matter.

category:             Algebra, Data, Math
abi:                  23f972172ea62bad13dc92ce63032e9f
exposed:              True
exposed-modules:
    Data.Semigroup.Commutative Numeric.Product.Commutative

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/commutative-semigroups-0.2.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/commutative-semigroups-0.2.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/commutative-semigroups-0.2.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commutative-semigroups
hs-libraries:         HScommutative-semigroups-0.2.0.2-KKbxYpGvMjb9AEMnknsNP1
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:
    /usr/share/doc/haskell-commutative-semigroups/html/commutative-semigroups.haddock

haddock-html:         /usr/share/doc/haskell-commutative-semigroups/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
